#!/usr/bin/python3
# -*- coding: utf-8 -*-
# @Time    : 2022/9/14 18:41
# @Author  : jia666666
# @FileName: __init__.py.py


from .core import headers_format,fidder_to_python3,get_html_text

__all__ = (
    headers_format,
    fidder_to_python3,
    get_html_text
)
